@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,10 @@
 
 
 
+
+from .fetchers import NUDeploymentFailuresFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -39,7 +43,7 @@ class NUBGPNeighbor(NURESTObject):
     """ Represents a BGPNeighbor in the VSD
 
         Notes:
-            None
+            Virtual Cloud Services (VCS) in the data center BGP PE-CE is configured at vport level . Network Service Gateways (NSG) BGP is configured at subnet level.
     """
 
     __rest_name__ = "bgpneighbor"
@@ -48,6 +52,10 @@ class NUBGPNeighbor(NURESTObject):
     
     ## Constants
     
+    CONST_IP_TYPE_IPV6 = "IPV6"
+    
+    CONST_IP_TYPE_IPV4 = "IPV4"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
@@ -71,24 +79,34 @@ class NUBGPNeighbor(NURESTObject):
 
         # Read/Write Attributes
         
+        self._bfd_enabled = None
+        self._ip_type = None
+        self._ipv6_address = None
         self._name = None
         self._dampening_enabled = None
         self._peer_as = None
+        self._peer_configuration = None
         self._peer_ip = None
         self._description = None
         self._session = None
         self._entity_scope = None
+        self._domain_service_label = None
         self._associated_export_routing_policy_id = None
         self._associated_import_routing_policy_id = None
         self._external_id = None
         
+        self.expose_attribute(local_name="bfd_enabled", remote_name="BFDEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="dampening_enabled", remote_name="dampeningEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer_as", remote_name="peerAS", attribute_type=int, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="peer_configuration", remote_name="peerConfiguration", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer_ip", remote_name="peerIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="session", remote_name="session", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="domain_service_label", remote_name="domainServiceLabel", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_export_routing_policy_id", remote_name="associatedExportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_import_routing_policy_id", remote_name="associatedImportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -97,6 +115,9 @@ class NUBGPNeighbor(NURESTObject):
         # Fetchers
         
         
+        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -107,6 +128,87 @@ class NUBGPNeighbor(NURESTObject):
 
     # Properties
     
+    @property
+    def bfd_enabled(self):
+        """ Get bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this BGP neighbor
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        return self._bfd_enabled
+
+    @bfd_enabled.setter
+    def bfd_enabled(self, value):
+        """ Set bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this BGP neighbor
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        self._bfd_enabled = value
+
+    
+    @property
+    def ip_type(self):
+        """ Get ip_type value.
+
+            Notes:
+                It can be either IPv4 or IPv6
+
+                
+                This attribute is named `IPType` in VSD API.
+                
+        """
+        return self._ip_type
+
+    @ip_type.setter
+    def ip_type(self, value):
+        """ Set ip_type value.
+
+            Notes:
+                It can be either IPv4 or IPv6
+
+                
+                This attribute is named `IPType` in VSD API.
+                
+        """
+        self._ip_type = value
+
+    
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                Peer IPv6 address
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                Peer IPv6 address
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -162,7 +264,7 @@ class NUBGPNeighbor(NURESTObject):
         """ Get peer_as value.
 
             Notes:
-                Local autonomous system to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.
+                Autonomous System (AS) value to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.
 
                 
                 This attribute is named `peerAS` in VSD API.
@@ -175,7 +277,7 @@ class NUBGPNeighbor(NURESTObject):
         """ Set peer_as value.
 
             Notes:
-                Local autonomous system to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.
+                Autonomous System (AS) value to be used when establishing a session with the remote peer if it is different from the global BGP router autonomous system number.
 
                 
                 This attribute is named `peerAS` in VSD API.
@@ -184,6 +286,33 @@ class NUBGPNeighbor(NURESTObject):
         self._peer_as = value
 
     
+    @property
+    def peer_configuration(self):
+        """ Get peer_configuration value.
+
+            Notes:
+                BGP Peer session configuration and default policies.
+
+                
+                This attribute is named `peerConfiguration` in VSD API.
+                
+        """
+        return self._peer_configuration
+
+    @peer_configuration.setter
+    def peer_configuration(self, value):
+        """ Set peer_configuration value.
+
+            Notes:
+                BGP Peer session configuration and default policies.
+
+                
+                This attribute is named `peerConfiguration` in VSD API.
+                
+        """
+        self._peer_configuration = value
+
+    
     @property
     def peer_ip(self):
         """ Get peer_ip value.
@@ -284,6 +413,33 @@ class NUBGPNeighbor(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def domain_service_label(self):
+        """ Get domain_service_label value.
+
+            Notes:
+                Service ID or external label given to Domain
+
+                
+                This attribute is named `domainServiceLabel` in VSD API.
+                
+        """
+        return self._domain_service_label
+
+    @domain_service_label.setter
+    def domain_service_label(self, value):
+        """ Set domain_service_label value.
+
+            Notes:
+                Service ID or external label given to Domain
+
+                
+                This attribute is named `domainServiceLabel` in VSD API.
+                
+        """
+        self._domain_service_label = value
+
+    
     @property
     def associated_export_routing_policy_id(self):
         """ Get associated_export_routing_policy_id value.
