@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -107,6 +108,7 @@ class NUEnterpriseProfile(NURESTObject):
         self._vnf_management_enabled = None
         self._name = None
         self._last_updated_by = None
+        self._web_filter_enabled = None
         self._receive_multi_cast_list_id = None
         self._send_multi_cast_list_id = None
         self._description = None
@@ -125,6 +127,7 @@ class NUEnterpriseProfile(NURESTObject):
         self.expose_attribute(local_name="vnf_management_enabled", remote_name="VNFManagementEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_enabled", remote_name="webFilterEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="receive_multi_cast_list_id", remote_name="receiveMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="send_multi_cast_list_id", remote_name="sendMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -292,6 +295,33 @@ class NUEnterpriseProfile(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def web_filter_enabled(self):
+        """ Get web_filter_enabled value.
+
+            Notes:
+                Enable Web Filtering for this enterprise profile
+
+                
+                This attribute is named `webFilterEnabled` in VSD API.
+                
+        """
+        return self._web_filter_enabled
+
+    @web_filter_enabled.setter
+    def web_filter_enabled(self, value):
+        """ Set web_filter_enabled value.
+
+            Notes:
+                Enable Web Filtering for this enterprise profile
+
+                
+                This attribute is named `webFilterEnabled` in VSD API.
+                
+        """
+        self._web_filter_enabled = value
+
+    
     @property
     def receive_multi_cast_list_id(self):
         """ Get receive_multi_cast_list_id value.
