@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,10 @@
 
 
 
+
+from .fetchers import NUGatewaysFetcher
+
+
 from .fetchers import NUTCAsFetcher
 
 
@@ -36,21 +40,45 @@ from .fetchers import NUAddressRangesFetcher
 from .fetchers import NURedirectionTargetsFetcher
 
 
+from .fetchers import NURedundancyGroupsFetcher
+
+
+from .fetchers import NUDeploymentFailuresFetcher
+
+
 from .fetchers import NUPermissionsFetcher
 
 
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUNetworkPerformanceBindingsFetcher
+
+
+from .fetchers import NUPGExpressionsFetcher
+
+
 from .fetchers import NUEgressACLEntryTemplatesFetcher
 
 
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUEgressAdvFwdTemplatesFetcher
+
+
 from .fetchers import NUDHCPOptionsFetcher
 
 
+from .fetchers import NUVirtualFirewallPoliciesFetcher
+
+
+from .fetchers import NUVirtualFirewallRulesFetcher
+
+
+from .fetchers import NUAlarmsFetcher
+
+
 from .fetchers import NUGlobalMetadatasFetcher
 
 
@@ -69,9 +97,6 @@ from .fetchers import NUIngressACLTemplatesFetcher
 from .fetchers import NUIngressAdvFwdTemplatesFetcher
 
 
-from .fetchers import NUIngressExternalServiceTemplatesFetcher
-
-
 from .fetchers import NUJobsFetcher
 
 
@@ -99,6 +124,9 @@ from .fetchers import NUVPNConnectionsFetcher
 from .fetchers import NUVPortsFetcher
 
 
+from .fetchers import NUApplicationsFetcher
+
+
 from .fetchers import NUApplicationperformancemanagementbindingsFetcher
 
 
@@ -108,6 +136,12 @@ from .fetchers import NUBridgeInterfacesFetcher
 from .fetchers import NUGroupsFetcher
 
 
+from .fetchers import NUProxyARPFiltersFetcher
+
+
+from .fetchers import NUNSGatewaySummariesFetcher
+
+
 from .fetchers import NUStaticRoutesFetcher
 
 
@@ -119,6 +153,9 @@ from .fetchers import NUStatisticsPoliciesFetcher
 
 from .fetchers import NUEventLogsFetcher
 
+
+from .fetchers import NUOverlayMirrorDestinationsFetcher
+
 from bambou import NURESTObject
 
 
@@ -135,23 +172,35 @@ class NUL2Domain(NURESTObject):
     
     ## Constants
     
-    CONST_UPLINK_PREFERENCE_SECONDARY_PRIMARY = "SECONDARY_PRIMARY"
+    CONST_UPLINK_PREFERENCE_PRIMARY_SECONDARY = "PRIMARY_SECONDARY"
+    
+    CONST_FLOW_COLLECTION_ENABLED_INHERITED = "INHERITED"
     
     CONST_DPI_ENABLED = "ENABLED"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
-    CONST_POLICY_CHANGE_STATUS_DISCARDED = "DISCARDED"
+    CONST_ENTITY_STATE_MARKED_FOR_DELETION = "MARKED_FOR_DELETION"
+    
+    CONST_IP_TYPE_IPV4 = "IPV4"
     
     CONST_MAINTENANCE_MODE_DISABLED = "DISABLED"
     
+    CONST_USE_GLOBAL_MAC_ENABLED = "ENABLED"
+    
     CONST_MAINTENANCE_MODE_ENABLED = "ENABLED"
     
     CONST_UPLINK_PREFERENCE_SYMMETRIC = "SYMMETRIC"
     
+    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
+    
+    CONST_USE_GLOBAL_MAC_DISABLED = "DISABLED"
+    
     CONST_POLICY_CHANGE_STATUS_STARTED = "STARTED"
     
-    CONST_UPLINK_PREFERENCE_PRIMARY_SECONDARY = "PRIMARY_SECONDARY"
+    CONST_UPLINK_PREFERENCE_SECONDARY_PRIMARY = "SECONDARY_PRIMARY"
+    
+    CONST_ENTITY_STATE_UNDER_CONSTRUCTION = "UNDER_CONSTRUCTION"
     
     CONST_MULTICAST_ENABLED = "ENABLED"
     
@@ -161,24 +210,26 @@ class NUL2Domain(NURESTObject):
     
     CONST_UPLINK_PREFERENCE_SECONDARY = "SECONDARY"
     
+    CONST_FLOW_COLLECTION_ENABLED_ENABLED = "ENABLED"
+    
     CONST_MULTICAST_DISABLED = "DISABLED"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_ENCRYPTION_DISABLED = "DISABLED"
     
-    CONST_IP_TYPE_IPV4 = "IPV4"
+    CONST_UPLINK_PREFERENCE_PRIMARY = "PRIMARY"
     
     CONST_DPI_DISABLED = "DISABLED"
     
-    CONST_UPLINK_PREFERENCE_PRIMARY = "PRIMARY"
-    
     CONST_MAINTENANCE_MODE_ENABLED_INHERITED = "ENABLED_INHERITED"
     
     CONST_ENCRYPTION_ENABLED = "ENABLED"
     
     CONST_IP_TYPE_DUALSTACK = "DUALSTACK"
     
+    CONST_POLICY_CHANGE_STATUS_DISCARDED = "DISCARDED"
+    
     
 
     def __init__(self, **kwargs):
@@ -201,6 +252,9 @@ class NUL2Domain(NURESTObject):
         self._dhcp_managed = None
         self._dpi = None
         self._ip_type = None
+        self._ipv6_address = None
+        self._ipv6_gateway = None
+        self._vxlanecmp_enabled = None
         self._maintenance_mode = None
         self._name = None
         self._last_updated_by = None
@@ -211,22 +265,33 @@ class NUL2Domain(NURESTObject):
         self._service_id = None
         self._description = None
         self._netmask = None
+        self._flow_collection_enabled = None
         self._vn_id = None
         self._encryption = None
+        self._ingress_replication_enabled = None
         self._entity_scope = None
+        self._entity_state = None
         self._policy_change_status = None
         self._route_distinguisher = None
         self._route_target = None
+        self._routed_vpls_enabled = None
         self._uplink_preference = None
+        self._use_global_mac = None
         self._associated_multicast_channel_map_id = None
         self._associated_shared_network_resource_id = None
+        self._associated_underlay_id = None
         self._stretched = None
         self._multicast = None
+        self._customer_id = None
         self._external_id = None
+        self._dynamic_ipv6_address = None
         
         self.expose_attribute(local_name="dhcp_managed", remote_name="DHCPManaged", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DUALSTACK', u'IPV4'])
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vxlanecmp_enabled", remote_name="VXLANECMPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENABLED_INHERITED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -237,23 +302,34 @@ class NUL2Domain(NURESTObject):
         self.expose_attribute(local_name="service_id", remote_name="serviceID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="vn_id", remote_name="vnId", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="ingress_replication_enabled", remote_name="ingressReplicationEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="entity_state", remote_name="entityState", attribute_type=str, is_required=False, is_unique=False, choices=[u'MARKED_FOR_DELETION', u'UNDER_CONSTRUCTION'])
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
         self.expose_attribute(local_name="route_distinguisher", remote_name="routeDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="route_target", remote_name="routeTarget", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="routed_vpls_enabled", remote_name="routedVPLSEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_preference", remote_name="uplinkPreference", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'PRIMARY_SECONDARY', u'SECONDARY', u'SECONDARY_PRIMARY', u'SYMMETRIC'])
+        self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_shared_network_resource_id", remote_name="associatedSharedNetworkResourceID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_underlay_id", remote_name="associatedUnderlayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stretched", remote_name="stretched", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
+        self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_ipv6_address", remote_name="dynamicIpv6Address", attribute_type=bool, is_required=False, is_unique=False)
         
 
         # Fetchers
         
         
+        self.gateways = NUGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.tcas = NUTCAsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -263,21 +339,45 @@ class NUL2Domain(NURESTObject):
         self.redirection_targets = NURedirectionTargetsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.redundancy_groups = NURedundancyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.network_performance_bindings = NUNetworkPerformanceBindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.pg_expressions = NUPGExpressionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.egress_acl_entry_templates = NUEgressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.egress_adv_fwd_templates = NUEgressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.dhcp_options = NUDHCPOptionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.virtual_firewall_policies = NUVirtualFirewallPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.virtual_firewall_rules = NUVirtualFirewallRulesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.alarms = NUAlarmsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -296,9 +396,6 @@ class NUL2Domain(NURESTObject):
         self.ingress_adv_fwd_templates = NUIngressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.ingress_external_service_templates = NUIngressExternalServiceTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -326,6 +423,9 @@ class NUL2Domain(NURESTObject):
         self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.applications = NUApplicationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.applicationperformancemanagementbindings = NUApplicationperformancemanagementbindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -335,6 +435,12 @@ class NUL2Domain(NURESTObject):
         self.groups = NUGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.proxy_arp_filters = NUProxyARPFiltersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ns_gateway_summaries = NUNSGatewaySummariesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.static_routes = NUStaticRoutesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -346,6 +452,9 @@ class NUL2Domain(NURESTObject):
         
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
+        
+        self.overlay_mirror_destinations = NUOverlayMirrorDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
 
         self._compute_args(**kwargs)
 
@@ -432,6 +541,87 @@ class NUL2Domain(NURESTObject):
         self._ip_type = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPV6 address of the route - Optional
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPV6 address of the route - Optional
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
+    @property
+    def ipv6_gateway(self):
+        """ Get ipv6_gateway value.
+
+            Notes:
+                The IPv6 address of the gateway of this subnet
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        return self._ipv6_gateway
+
+    @ipv6_gateway.setter
+    def ipv6_gateway(self, value):
+        """ Set ipv6_gateway value.
+
+            Notes:
+                The IPv6 address of the gateway of this subnet
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        self._ipv6_gateway = value
+
+    
+    @property
+    def vxlanecmp_enabled(self):
+        """ Get vxlanecmp_enabled value.
+
+            Notes:
+                Determines whether VXLAN-ECMP are enabled on this domain.
+
+                
+                This attribute is named `VXLANECMPEnabled` in VSD API.
+                
+        """
+        return self._vxlanecmp_enabled
+
+    @vxlanecmp_enabled.setter
+    def vxlanecmp_enabled(self, value):
+        """ Set vxlanecmp_enabled value.
+
+            Notes:
+                Determines whether VXLAN-ECMP are enabled on this domain.
+
+                
+                This attribute is named `VXLANECMPEnabled` in VSD API.
+                
+        """
+        self._vxlanecmp_enabled = value
+
+    
     @property
     def maintenance_mode(self):
         """ Get maintenance_mode value.
@@ -682,12 +872,39 @@ class NUL2Domain(NURESTObject):
         self._netmask = value
 
     
+    @property
+    def flow_collection_enabled(self):
+        """ Get flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        return self._flow_collection_enabled
+
+    @flow_collection_enabled.setter
+    def flow_collection_enabled(self, value):
+        """ Set flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        self._flow_collection_enabled = value
+
+    
     @property
     def vn_id(self):
         """ Get vn_id value.
 
             Notes:
-                Current Network's  globally unique  VXLAN network identifier generated by VSD
+                Current network's globally unique VXLAN network identifier
 
                 
                 This attribute is named `vnId` in VSD API.
@@ -700,7 +917,7 @@ class NUL2Domain(NURESTObject):
         """ Set vn_id value.
 
             Notes:
-                Current Network's  globally unique  VXLAN network identifier generated by VSD
+                Current network's globally unique VXLAN network identifier
 
                 
                 This attribute is named `vnId` in VSD API.
@@ -732,6 +949,33 @@ class NUL2Domain(NURESTObject):
         self._encryption = value
 
     
+    @property
+    def ingress_replication_enabled(self):
+        """ Get ingress_replication_enabled value.
+
+            Notes:
+                Enables ingress replication for the VNI.
+
+                
+                This attribute is named `ingressReplicationEnabled` in VSD API.
+                
+        """
+        return self._ingress_replication_enabled
+
+    @ingress_replication_enabled.setter
+    def ingress_replication_enabled(self, value):
+        """ Set ingress_replication_enabled value.
+
+            Notes:
+                Enables ingress replication for the VNI.
+
+                
+                This attribute is named `ingressReplicationEnabled` in VSD API.
+                
+        """
+        self._ingress_replication_enabled = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -759,6 +1003,33 @@ class NUL2Domain(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def entity_state(self):
+        """ Get entity_state value.
+
+            Notes:
+                Intermediate State of L2 Domain.
+
+                
+                This attribute is named `entityState` in VSD API.
+                
+        """
+        return self._entity_state
+
+    @entity_state.setter
+    def entity_state(self, value):
+        """ Set entity_state value.
+
+            Notes:
+                Intermediate State of L2 Domain.
+
+                
+                This attribute is named `entityState` in VSD API.
+                
+        """
+        self._entity_state = value
+
+    
     @property
     def policy_change_status(self):
         """ Get policy_change_status value.
@@ -791,7 +1062,7 @@ class NUL2Domain(NURESTObject):
         """ Get route_distinguisher value.
 
             Notes:
-                The Route Distinguisher value assigned by VSD for this subnet that is used by the BGP-EVPN protocol in VSC
+                Route distinguisher that is used by the BGP-EVPN protocol in VSC. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeDistinguisher` in VSD API.
@@ -804,7 +1075,7 @@ class NUL2Domain(NURESTObject):
         """ Set route_distinguisher value.
 
             Notes:
-                The Route Distinguisher value assigned by VSD for this subnet that is used by the BGP-EVPN protocol in VSC
+                Route distinguisher that is used by the BGP-EVPN protocol in VSC. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeDistinguisher` in VSD API.
@@ -818,7 +1089,7 @@ class NUL2Domain(NURESTObject):
         """ Get route_target value.
 
             Notes:
-                The Route Target value assigned by VSD for this subnet that is used by the BGP-EVPN protocol in VSC
+                Route target that is used by the BGP-EVPN protocol in VSC. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeTarget` in VSD API.
@@ -831,7 +1102,7 @@ class NUL2Domain(NURESTObject):
         """ Set route_target value.
 
             Notes:
-                The Route Target value assigned by VSD for this subnet that is used by the BGP-EVPN protocol in VSC
+                Route target that is used by the BGP-EVPN protocol in VSC. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeTarget` in VSD API.
@@ -840,6 +1111,33 @@ class NUL2Domain(NURESTObject):
         self._route_target = value
 
     
+    @property
+    def routed_vpls_enabled(self):
+        """ Get routed_vpls_enabled value.
+
+            Notes:
+                Determines whether routed VPLS services are enabled on this domain.
+
+                
+                This attribute is named `routedVPLSEnabled` in VSD API.
+                
+        """
+        return self._routed_vpls_enabled
+
+    @routed_vpls_enabled.setter
+    def routed_vpls_enabled(self, value):
+        """ Set routed_vpls_enabled value.
+
+            Notes:
+                Determines whether routed VPLS services are enabled on this domain.
+
+                
+                This attribute is named `routedVPLSEnabled` in VSD API.
+                
+        """
+        self._routed_vpls_enabled = value
+
+    
     @property
     def uplink_preference(self):
         """ Get uplink_preference value.
@@ -867,6 +1165,33 @@ class NUL2Domain(NURESTObject):
         self._uplink_preference = value
 
     
+    @property
+    def use_global_mac(self):
+        """ Get use_global_mac value.
+
+            Notes:
+                Enable this flag to use system configured globalMACAddress as the gateway mac address for managed l2 domains
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        return self._use_global_mac
+
+    @use_global_mac.setter
+    def use_global_mac(self, value):
+        """ Set use_global_mac value.
+
+            Notes:
+                Enable this flag to use system configured globalMACAddress as the gateway mac address for managed l2 domains
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        self._use_global_mac = value
+
+    
     @property
     def associated_multicast_channel_map_id(self):
         """ Get associated_multicast_channel_map_id value.
@@ -921,6 +1246,33 @@ class NUL2Domain(NURESTObject):
         self._associated_shared_network_resource_id = value
 
     
+    @property
+    def associated_underlay_id(self):
+        """ Get associated_underlay_id value.
+
+            Notes:
+                The ID of the Underlay entity to which this L2 Domain is associated.
+
+                
+                This attribute is named `associatedUnderlayID` in VSD API.
+                
+        """
+        return self._associated_underlay_id
+
+    @associated_underlay_id.setter
+    def associated_underlay_id(self, value):
+        """ Set associated_underlay_id value.
+
+            Notes:
+                The ID of the Underlay entity to which this L2 Domain is associated.
+
+                
+                This attribute is named `associatedUnderlayID` in VSD API.
+                
+        """
+        self._associated_underlay_id = value
+
+    
     @property
     def stretched(self):
         """ Get stretched value.
@@ -967,6 +1319,33 @@ class NUL2Domain(NURESTObject):
         self._multicast = value
 
     
+    @property
+    def customer_id(self):
+        """ Get customer_id value.
+
+            Notes:
+                CustomerID that is used by NETCONF MANAGER to identify this enterprise. This can be configured by root user.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        return self._customer_id
+
+    @customer_id.setter
+    def customer_id(self, value):
+        """ Set customer_id value.
+
+            Notes:
+                CustomerID that is used by NETCONF MANAGER to identify this enterprise. This can be configured by root user.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        self._customer_id = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
@@ -994,6 +1373,33 @@ class NUL2Domain(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_ipv6_address(self):
+        """ Get dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        return self._dynamic_ipv6_address
+
+    @dynamic_ipv6_address.setter
+    def dynamic_ipv6_address(self, value):
+        """ Set dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        self._dynamic_ipv6_address = value
+
+    
 
     
     ## Custom methods
