@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,15 +27,25 @@
 
 
 
+
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUShuntLinksFetcher
+
+
 from .fetchers import NUAlarmsFetcher
 
 
 from .fetchers import NUGlobalMetadatasFetcher
 
 
+from .fetchers import NUEnterprisePermissionsFetcher
+
+
 from .fetchers import NUNSGatewaysFetcher
 
 
@@ -60,39 +70,49 @@ class NUNSRedundantGatewayGroup(NURESTObject):
     
     ## Constants
     
-    CONST_PERSONALITY_HARDWARE_VTEP = "HARDWARE_VTEP"
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
-    CONST_PERSONALITY_VSA = "VSA"
-    
-    CONST_PERMITTED_ACTION_ALL = "ALL"
-    
-    CONST_PERSONALITY_VSG = "VSG"
-    
-    CONST_PERMITTED_ACTION_READ = "READ"
+    CONST_PERSONALITY_NSGDUC = "NSGDUC"
     
     CONST_PERSONALITY_OTHER = "OTHER"
     
     CONST_PERSONALITY_NSG = "NSG"
     
-    CONST_REDUNDANT_GATEWAY_STATUS_SUCCESS = "SUCCESS"
-    
-    CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
-    
     CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
     
-    CONST_PERMITTED_ACTION_USE = "USE"
-    
-    CONST_PERSONALITY_VRSG = "VRSG"
-    
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
     CONST_PERSONALITY_DC7X50 = "DC7X50"
     
+    CONST_REDUNDANT_GATEWAY_STATUS_FAILED = "FAILED"
+    
+    CONST_PERSONALITY_HARDWARE_VTEP = "HARDWARE_VTEP"
+    
+    CONST_PERSONALITY_VSA = "VSA"
+    
+    CONST_PERMITTED_ACTION_USE = "USE"
+    
+    CONST_PERSONALITY_VSG = "VSG"
+    
+    CONST_PERMITTED_ACTION_READ = "READ"
+    
+    CONST_PERSONALITY_VRSB = "VRSB"
+    
+    CONST_REDUNDANT_GATEWAY_STATUS_SUCCESS = "SUCCESS"
+    
+    CONST_PERSONALITY_NUAGE_210_WBX_48_S = "NUAGE_210_WBX_48_S"
+    
+    CONST_PERSONALITY_VRSG = "VRSG"
+    
+    CONST_PERSONALITY_NUAGE_210_WBX_32_Q = "NUAGE_210_WBX_32_Q"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    CONST_PERMITTED_ACTION_ALL = "ALL"
     
-    CONST_REDUNDANT_GATEWAY_STATUS_FAILED = "FAILED"
+    CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
+    
+    CONST_PERSONALITY_NSGBR = "NSGBR"
     
     
 
@@ -116,9 +136,12 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         self._name = None
         self._last_updated_by = None
         self._gateway_peer1_autodiscovered_gateway_id = None
+        self._gateway_peer1_connected = None
         self._gateway_peer1_id = None
         self._gateway_peer1_name = None
         self._gateway_peer2_autodiscovered_gateway_id = None
+        self._gateway_peer2_connected = None
+        self._gateway_peer2_id = None
         self._gateway_peer2_name = None
         self._heartbeat_interval = None
         self._heartbeat_vlanid = None
@@ -135,16 +158,19 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer1_autodiscovered_gateway_id", remote_name="gatewayPeer1AutodiscoveredGatewayID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="gateway_peer1_id", remote_name="gatewayPeer1ID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_peer1_connected", remote_name="gatewayPeer1Connected", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_peer1_id", remote_name="gatewayPeer1ID", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="gateway_peer1_name", remote_name="gatewayPeer1Name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer2_autodiscovered_gateway_id", remote_name="gatewayPeer2AutodiscoveredGatewayID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_peer2_connected", remote_name="gatewayPeer2Connected", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_peer2_id", remote_name="gatewayPeer2ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer2_name", remote_name="gatewayPeer2Name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="heartbeat_interval", remote_name="heartbeatInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="heartbeat_vlanid", remote_name="heartbeatVLANID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="redundancy_port_ids", remote_name="redundancyPortIDs", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="redundant_gateway_status", remote_name="redundantGatewayStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'FAILED', u'SUCCESS'])
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
-        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'HARDWARE_VTEP', u'NSG', u'OTHER', u'VRSG', u'VSA', u'VSG'])
+        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'HARDWARE_VTEP', u'NSG', u'NSGBR', u'NSGDUC', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'OTHER', u'VRSB', u'VRSG', u'VSA', u'VSG'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
@@ -155,15 +181,24 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.shunt_links = NUShuntLinksFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.alarms = NUAlarmsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ns_gateways = NUNSGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -254,6 +289,33 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         self._gateway_peer1_autodiscovered_gateway_id = value
 
     
+    @property
+    def gateway_peer1_connected(self):
+        """ Get gateway_peer1_connected value.
+
+            Notes:
+                Indicates status of the authoritative gateway of this Redundancy Group.
+
+                
+                This attribute is named `gatewayPeer1Connected` in VSD API.
+                
+        """
+        return self._gateway_peer1_connected
+
+    @gateway_peer1_connected.setter
+    def gateway_peer1_connected(self, value):
+        """ Set gateway_peer1_connected value.
+
+            Notes:
+                Indicates status of the authoritative gateway of this Redundancy Group.
+
+                
+                This attribute is named `gatewayPeer1Connected` in VSD API.
+                
+        """
+        self._gateway_peer1_connected = value
+
+    
     @property
     def gateway_peer1_id(self):
         """ Get gateway_peer1_id value.
@@ -286,7 +348,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get gateway_peer1_name value.
 
             Notes:
-                The gateway   configuration owner name in this Redundant Group
+                The name of the authoritative gateway owning the configuration for the Redundant Group
 
                 
                 This attribute is named `gatewayPeer1Name` in VSD API.
@@ -299,7 +361,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set gateway_peer1_name value.
 
             Notes:
-                The gateway   configuration owner name in this Redundant Group
+                The name of the authoritative gateway owning the configuration for the Redundant Group
 
                 
                 This attribute is named `gatewayPeer1Name` in VSD API.
@@ -313,7 +375,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get gateway_peer2_autodiscovered_gateway_id value.
 
             Notes:
-                The Auto Discovered Gateway  peer in this Redundant Group
+                The Auto Discovered Gateway configuration for the secondary gateway in this Redundant Group.
 
                 
                 This attribute is named `gatewayPeer2AutodiscoveredGatewayID` in VSD API.
@@ -326,7 +388,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set gateway_peer2_autodiscovered_gateway_id value.
 
             Notes:
-                The Auto Discovered Gateway  peer in this Redundant Group
+                The Auto Discovered Gateway configuration for the secondary gateway in this Redundant Group.
 
                 
                 This attribute is named `gatewayPeer2AutodiscoveredGatewayID` in VSD API.
@@ -335,12 +397,66 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         self._gateway_peer2_autodiscovered_gateway_id = value
 
     
+    @property
+    def gateway_peer2_connected(self):
+        """ Get gateway_peer2_connected value.
+
+            Notes:
+                Indicates status of the secondary gateway of this Redundancy Group.
+
+                
+                This attribute is named `gatewayPeer2Connected` in VSD API.
+                
+        """
+        return self._gateway_peer2_connected
+
+    @gateway_peer2_connected.setter
+    def gateway_peer2_connected(self, value):
+        """ Set gateway_peer2_connected value.
+
+            Notes:
+                Indicates status of the secondary gateway of this Redundancy Group.
+
+                
+                This attribute is named `gatewayPeer2Connected` in VSD API.
+                
+        """
+        self._gateway_peer2_connected = value
+
+    
+    @property
+    def gateway_peer2_id(self):
+        """ Get gateway_peer2_id value.
+
+            Notes:
+                The gateway peer in this Redundant Group. when Redundant Group is deleted this gateway will not recieve vport associations
+
+                
+                This attribute is named `gatewayPeer2ID` in VSD API.
+                
+        """
+        return self._gateway_peer2_id
+
+    @gateway_peer2_id.setter
+    def gateway_peer2_id(self, value):
+        """ Set gateway_peer2_id value.
+
+            Notes:
+                The gateway peer in this Redundant Group. when Redundant Group is deleted this gateway will not recieve vport associations
+
+                
+                This attribute is named `gatewayPeer2ID` in VSD API.
+                
+        """
+        self._gateway_peer2_id = value
+
+    
     @property
     def gateway_peer2_name(self):
         """ Get gateway_peer2_name value.
 
             Notes:
-                The gateway peer name in this Redundant Group
+                The secondary gateway peer name in this Redundant Group.
 
                 
                 This attribute is named `gatewayPeer2Name` in VSD API.
@@ -353,7 +469,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set gateway_peer2_name value.
 
             Notes:
-                The gateway peer name in this Redundant Group
+                The secondary gateway peer name in this Redundant Group.
 
                 
                 This attribute is named `gatewayPeer2Name` in VSD API.
@@ -367,7 +483,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get heartbeat_interval value.
 
             Notes:
-                Heartbeat interval in milliseconds to declare the neighbor dead.
+                Heartbeat interval in milliseconds to declare the neighbor as dead.
 
                 
                 This attribute is named `heartbeatInterval` in VSD API.
@@ -380,7 +496,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set heartbeat_interval value.
 
             Notes:
-                Heartbeat interval in milliseconds to declare the neighbor dead.
+                Heartbeat interval in milliseconds to declare the neighbor as dead.
 
                 
                 This attribute is named `heartbeatInterval` in VSD API.
@@ -421,7 +537,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get redundancy_port_ids value.
 
             Notes:
-                Collections resilient port ids associated with this redundant group.
+                Collections resilient port IDs associated with this redundant group.
 
                 
                 This attribute is named `redundancyPortIDs` in VSD API.
@@ -434,7 +550,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set redundancy_port_ids value.
 
             Notes:
-                Collections resilient port ids associated with this redundant group.
+                Collections resilient port IDs associated with this redundant group.
 
                 
                 This attribute is named `redundancyPortIDs` in VSD API.
@@ -448,7 +564,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get redundant_gateway_status value.
 
             Notes:
-                The status of  Redundant Group.
+                The status of the Redundant Group.
 
                 
                 This attribute is named `redundantGatewayStatus` in VSD API.
@@ -461,7 +577,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set redundant_gateway_status value.
 
             Notes:
-                The status of  Redundant Group.
+                The status of the Redundant Group.
 
                 
                 This attribute is named `redundantGatewayStatus` in VSD API.
@@ -475,7 +591,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this Gateway.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -488,7 +604,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this Gateway.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -525,7 +641,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get description value.
 
             Notes:
-                 Description of the Redundancy Group
+                Description of the Redundancy Group
 
                 
         """
@@ -536,7 +652,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set description value.
 
             Notes:
-                 Description of the Redundancy Group
+                Description of the Redundancy Group
 
                 
         """
@@ -602,7 +718,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Get consecutive_failures_count value.
 
             Notes:
-                Consecutive failure count.
+                Consecutive failure count.  Supported value is 3.
 
                 
                 This attribute is named `consecutiveFailuresCount` in VSD API.
@@ -615,7 +731,7 @@ class NUNSRedundantGatewayGroup(NURESTObject):
         """ Set consecutive_failures_count value.
 
             Notes:
-                Consecutive failure count.
+                Consecutive failure count.  Supported value is 3.
 
                 
                 This attribute is named `consecutiveFailuresCount` in VSD API.
