@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUPermissionsFetcher
 
 
@@ -54,7 +55,7 @@ class NUPort(NURESTObject):
     """ Represents a Port in the VSD
 
         Notes:
-            Represents Port under a particular gateway object or redundant group object.
+            A port represents specific connection point of a gateway. It can be used for internal networking, like an uplink connection or a management network. It can also be used for domain's access.
     """
 
     __rest_name__ = "port"
@@ -79,11 +80,13 @@ class NUPort(NURESTObject):
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_STATUS_MISMATCH = "MISMATCH"
+    
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
     CONST_STATUS_INITIALIZED = "INITIALIZED"
     
-    CONST_STATUS_MISMATCH = "MISMATCH"
+    CONST_PORT_TYPE_MANAGEMENT = "MANAGEMENT"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
@@ -135,7 +138,7 @@ class NUPort(NURESTObject):
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="physical_name", remote_name="physicalName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'NETWORK'])
+        self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'MANAGEMENT', u'NETWORK'])
         self.expose_attribute(local_name="is_resilient", remote_name="isResilient", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
@@ -386,7 +389,7 @@ class NUPort(NURESTObject):
         """ Get port_type value.
 
             Notes:
-                Type of the Port.
+                Type of the Port. Possible values are ACCESS, NETWORK, MANAGEMENT.
 
                 
                 This attribute is named `portType` in VSD API.
@@ -399,7 +402,7 @@ class NUPort(NURESTObject):
         """ Set port_type value.
 
             Notes:
-                Type of the Port.
+                Type of the Port. Possible values are ACCESS, NETWORK, MANAGEMENT.
 
                 
                 This attribute is named `portType` in VSD API.
