@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,12 +27,22 @@
 
 
 
+
+from .fetchers import NUMetadatasFetcher
+
+
+from .fetchers import NUGlobalMetadatasFetcher
+
+
 from .fetchers import NUVNFInterfacesFetcher
 
 
 from .fetchers import NUVNFMetadatasFetcher
 
 
+from .fetchers import NUVNFThresholdPoliciesFetcher
+
+
 from .fetchers import NUJobsFetcher
 
 from bambou import NURESTObject
@@ -42,7 +52,7 @@ class NUVNF(NURESTObject):
     """ Represents a VNF in the VSD
 
         Notes:
-            Represent a VNF instance
+            Instantiation of a VNF on a specified Network Services Gateway that has the resources to manage a VNF.
     """
 
     __rest_name__ = "vnf"
@@ -51,12 +61,24 @@ class NUVNF(NURESTObject):
     
     ## Constants
     
+    CONST_LAST_USER_ACTION_NONE = "NONE"
+    
     CONST_STATUS_SHUTDOWN = "SHUTDOWN"
     
+    CONST_LAST_USER_ACTION_START = "START"
+    
+    CONST_LAST_USER_ACTION_REDEPLOY = "REDEPLOY"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_LAST_USER_ACTION_RESTART = "RESTART"
+    
     CONST_TASK_STATE_STOPPING = "STOPPING"
     
     CONST_ALLOWED_ACTIONS_START = "START"
     
+    CONST_STATUS_SHUTOFF = "SHUTOFF"
+    
     CONST_STATUS_IDLE = "IDLE"
     
     CONST_TASK_STATE_NONE = "NONE"
@@ -67,7 +89,7 @@ class NUVNF(NURESTObject):
     
     CONST_TASK_STATE_DEPLOYING = "DEPLOYING"
     
-    CONST_STATUS_DYING = "DYING"
+    CONST_TYPE_WAN_OPT = "WAN_OPT"
     
     CONST_ALLOWED_ACTIONS_RESTART = "RESTART"
     
@@ -85,14 +107,24 @@ class NUVNF(NURESTObject):
     
     CONST_TASK_STATE_STARTING = "STARTING"
     
-    CONST_STATUS_SHUTOFF = "SHUTOFF"
+    CONST_STATUS_DYING = "DYING"
     
     CONST_ALLOWED_ACTIONS_REDEPLOY = "REDEPLOY"
     
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
+    CONST_LAST_USER_ACTION_UNDEPLOY = "UNDEPLOY"
+    
+    CONST_TYPE_FIREWALL = "FIREWALL"
+    
     CONST_ALLOWED_ACTIONS_STOP = "STOP"
     
+    CONST_LAST_USER_ACTION_DEPLOY = "DEPLOY"
+    
     CONST_STATUS_PMSUSPENDED = "PMSUSPENDED"
     
+    CONST_LAST_USER_ACTION_STOP = "STOP"
+    
     CONST_TASK_STATE_UNDEPLOYING = "UNDEPLOYING"
     
     
@@ -123,18 +155,23 @@ class NUVNF(NURESTObject):
         self._name = None
         self._task_state = None
         self._last_known_error = None
+        self._last_updated_by = None
+        self._last_user_action = None
         self._memory_mb = None
         self._vendor = None
         self._description = None
-        self._metadata_id = None
         self._allowed_actions = None
         self._enterprise_id = None
+        self._entity_scope = None
         self._is_attached_to_descriptor = None
         self._associated_vnf_metadata_id = None
+        self._associated_vnf_threshold_policy_id = None
         self._status = None
         self._storage_gb = None
+        self._external_id = None
+        self._type = None
         
-        self.expose_attribute(local_name="vnf_descriptor_id", remote_name="VNFDescriptorID", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="vnf_descriptor_id", remote_name="VNFDescriptorID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vnf_descriptor_name", remote_name="VNFDescriptorName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="cpu_count", remote_name="CPUCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nsg_name", remote_name="NSGName", attribute_type=str, is_required=False, is_unique=False)
@@ -143,27 +180,41 @@ class NUVNF(NURESTObject):
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="task_state", remote_name="taskState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DEPLOYING', u'NONE', u'STARTING', u'STOPPING', u'UNDEPLOYING'])
         self.expose_attribute(local_name="last_known_error", remote_name="lastKnownError", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_user_action", remote_name="lastUserAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'DEPLOY', u'NONE', u'REDEPLOY', u'RESTART', u'START', u'STOP', u'UNDEPLOY'])
         self.expose_attribute(local_name="memory_mb", remote_name="memoryMB", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vendor", remote_name="vendor", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="metadata_id", remote_name="metadataID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="allowed_actions", remote_name="allowedActions", attribute_type=str, is_required=False, is_unique=False, choices=[u'DEPLOY', u'REDEPLOY', u'RESTART', u'START', u'STOP', u'UNDEPLOY'])
+        self.expose_attribute(local_name="allowed_actions", remote_name="allowedActions", attribute_type=list, is_required=False, is_unique=False, choices=[u'DEPLOY', u'REDEPLOY', u'RESTART', u'START', u'STOP', u'UNDEPLOY'])
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="is_attached_to_descriptor", remote_name="isAttachedToDescriptor", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_vnf_metadata_id", remote_name="associatedVNFMetadataID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_vnf_threshold_policy_id", remote_name="associatedVNFThresholdPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'BLOCKED', u'CRASHED', u'DYING', u'IDLE', u'INIT', u'LAST', u'PAUSED', u'PMSUSPENDED', u'RUNNING', u'SHUTDOWN', u'SHUTOFF'])
         self.expose_attribute(local_name="storage_gb", remote_name="storageGB", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'FIREWALL', u'WAN_OPT'])
         
 
         # Fetchers
         
         
+        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.vnf_interfaces = NUVNFInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.vnf_metadatas = NUVNFMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.vnf_threshold_policies = NUVNFThresholdPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -176,7 +227,7 @@ class NUVNF(NURESTObject):
         """ Get vnf_descriptor_id value.
 
             Notes:
-                The ID of VNF Descriptor from which VNF to be created.
+                The ID of VNF Descriptor from which VNF to be created. This is required on creation and can be removed on moidification of VNF instance.
 
                 
                 This attribute is named `VNFDescriptorID` in VSD API.
@@ -189,7 +240,7 @@ class NUVNF(NURESTObject):
         """ Set vnf_descriptor_id value.
 
             Notes:
-                The ID of VNF Descriptor from which VNF to be created.
+                The ID of VNF Descriptor from which VNF to be created. This is required on creation and can be removed on moidification of VNF instance.
 
                 
                 This attribute is named `VNFDescriptorID` in VSD API.
@@ -410,6 +461,60 @@ class NUVNF(NURESTObject):
         self._last_known_error = value
 
     
+    @property
+    def last_updated_by(self):
+        """ Get last_updated_by value.
+
+            Notes:
+                ID of the user who last updated the object.
+
+                
+                This attribute is named `lastUpdatedBy` in VSD API.
+                
+        """
+        return self._last_updated_by
+
+    @last_updated_by.setter
+    def last_updated_by(self, value):
+        """ Set last_updated_by value.
+
+            Notes:
+                ID of the user who last updated the object.
+
+                
+                This attribute is named `lastUpdatedBy` in VSD API.
+                
+        """
+        self._last_updated_by = value
+
+    
+    @property
+    def last_user_action(self):
+        """ Get last_user_action value.
+
+            Notes:
+                Last action perform by user
+
+                
+                This attribute is named `lastUserAction` in VSD API.
+                
+        """
+        return self._last_user_action
+
+    @last_user_action.setter
+    def last_user_action(self, value):
+        """ Set last_user_action value.
+
+            Notes:
+                Last action perform by user
+
+                
+                This attribute is named `lastUserAction` in VSD API.
+                
+        """
+        self._last_user_action = value
+
+    
     @property
     def memory_mb(self):
         """ Get memory_mb value.
@@ -483,33 +588,6 @@ class NUVNF(NURESTObject):
         self._description = value
 
     
-    @property
-    def metadata_id(self):
-        """ Get metadata_id value.
-
-            Notes:
-                Id of referenced metadata object
-
-                
-                This attribute is named `metadataID` in VSD API.
-                
-        """
-        return self._metadata_id
-
-    @metadata_id.setter
-    def metadata_id(self, value):
-        """ Set metadata_id value.
-
-            Notes:
-                Id of referenced metadata object
-
-                
-                This attribute is named `metadataID` in VSD API.
-                
-        """
-        self._metadata_id = value
-
-    
     @property
     def allowed_actions(self):
         """ Get allowed_actions value.
@@ -564,6 +642,33 @@ class NUVNF(NURESTObject):
         self._enterprise_id = value
 
     
+    @property
+    def entity_scope(self):
+        """ Get entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        return self._entity_scope
+
+    @entity_scope.setter
+    def entity_scope(self, value):
+        """ Set entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        self._entity_scope = value
+
+    
     @property
     def is_attached_to_descriptor(self):
         """ Get is_attached_to_descriptor value.
@@ -618,6 +723,33 @@ class NUVNF(NURESTObject):
         self._associated_vnf_metadata_id = value
 
     
+    @property
+    def associated_vnf_threshold_policy_id(self):
+        """ Get associated_vnf_threshold_policy_id value.
+
+            Notes:
+                VNF threshold policy associated to VNF instance
+
+                
+                This attribute is named `associatedVNFThresholdPolicyID` in VSD API.
+                
+        """
+        return self._associated_vnf_threshold_policy_id
+
+    @associated_vnf_threshold_policy_id.setter
+    def associated_vnf_threshold_policy_id(self, value):
+        """ Set associated_vnf_threshold_policy_id value.
+
+            Notes:
+                VNF threshold policy associated to VNF instance
+
+                
+                This attribute is named `associatedVNFThresholdPolicyID` in VSD API.
+                
+        """
+        self._associated_vnf_threshold_policy_id = value
+
+    
     @property
     def status(self):
         """ Get status value.
@@ -668,5 +800,55 @@ class NUVNF(NURESTObject):
         self._storage_gb = value
 
     
+    @property
+    def external_id(self):
+        """ Get external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        return self._external_id
+
+    @external_id.setter
+    def external_id(self, value):
+        """ Set external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        self._external_id = value
+
+    
+    @property
+    def type(self):
+        """ Get type value.
+
+            Notes:
+                Type of virtual network function
+
+                
+        """
+        return self._type
+
+    @type.setter
+    def type(self, value):
+        """ Set type value.
+
+            Notes:
+                Type of virtual network function
+
+                
+        """
+        self._type = value
+
+    
 
     
\ No newline at end of file
