@@ -61,6 +61,8 @@ class NUCommand(NURESTObject):
     
     CONST_STATUS_ABANDONED = "ABANDONED"
     
+    CONST_COMMAND_NSG_RENEW_CERT = "NSG_RENEW_CERT"
+    
     CONST_COMMAND_UNKNOWN = "UNKNOWN"
     
     CONST_STATUS_FAILED = "FAILED"
@@ -75,7 +77,7 @@ class NUCommand(NURESTObject):
     
     CONST_COMMAND_NSG_OVERLAY_SYSLOG_CONTAINER_RESTART = "NSG_OVERLAY_SYSLOG_CONTAINER_RESTART"
     
-    CONST_COMMAND_NSG_RENEW_CERT = "NSG_RENEW_CERT"
+    CONST_COMMAND_NSG_CONTAINER_UNDERLAY_TEST = "NSG_CONTAINER_UNDERLAY_TEST"
     
     CONST_COMMAND_NSG_CONTAINER_TEST_SUITE_RUN = "NSG_CONTAINER_TEST_SUITE_RUN"
     
@@ -134,7 +136,7 @@ class NUCommand(NURESTObject):
         self.expose_attribute(local_name="detailed_status", remote_name="detailedStatus", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="detailed_status_code", remote_name="detailedStatusCode", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="command", remote_name="command", attribute_type=str, is_required=True, is_unique=False, choices=[u'NSG_APPLY_PATCH', u'NSG_CONTAINER_TEST_SUITE_RUN', u'NSG_DELETE_PATCH', u'NSG_DOWNLOAD_OS_IMAGE', u'NSG_OVERLAY_SYSLOG_CONTAINER_RESTART', u'NSG_OVERLAY_SYSLOG_CONTAINER_START', u'NSG_OVERLAY_SYSLOG_CONTAINER_STOP', u'NSG_REBOOT', u'NSG_RENEW_CERT', u'NSG_UPDATE_INFO', u'NSG_UPGRADE_TO_IMAGE', u'UNKNOWN'])
+        self.expose_attribute(local_name="command", remote_name="command", attribute_type=str, is_required=True, is_unique=False, choices=[u'NSG_APPLY_PATCH', u'NSG_CONTAINER_TEST_SUITE_RUN', u'NSG_CONTAINER_UNDERLAY_TEST', u'NSG_DELETE_PATCH', u'NSG_DOWNLOAD_OS_IMAGE', u'NSG_OVERLAY_SYSLOG_CONTAINER_RESTART', u'NSG_OVERLAY_SYSLOG_CONTAINER_START', u'NSG_OVERLAY_SYSLOG_CONTAINER_STOP', u'NSG_REBOOT', u'NSG_RENEW_CERT', u'NSG_UPDATE_INFO', u'NSG_UPGRADE_TO_IMAGE', u'UNKNOWN'])
         self.expose_attribute(local_name="command_information", remote_name="commandInformation", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="progress", remote_name="progress", attribute_type=str, is_required=False, is_unique=False)
