@@ -28,6 +28,9 @@
 
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -56,6 +59,10 @@ class NUOSPFInstance(NURESTObject):
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_OSPF_TYPE_OSPFV2 = "OSPFv2"
+    
+    CONST_OSPF_TYPE_OSPFV3 = "OSPFv3"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     
@@ -78,30 +85,38 @@ class NUOSPFInstance(NURESTObject):
         # Read/Write Attributes
         
         self._ip_type = None
+        self._ospf_type = None
         self._name = None
         self._last_updated_by = None
+        self._last_updated_date = None
         self._description = None
         self._embedded_metadata = None
         self._entity_scope = None
+        self._creation_date = None
         self._preference = None
         self._associated_export_routing_policy_id = None
         self._associated_import_routing_policy_id = None
         self._super_backbone_enabled = None
+        self._owner = None
         self._export_limit = None
         self._export_to_overlay = None
         self._external_id = None
         self._external_preference = None
         
         self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4'])
+        self.expose_attribute(local_name="ospf_type", remote_name="OSPFType", attribute_type=str, is_required=False, is_unique=True, choices=[u'OSPFv2', u'OSPFv3'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="preference", remote_name="preference", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_export_routing_policy_id", remote_name="associatedExportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_import_routing_policy_id", remote_name="associatedImportRoutingPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="super_backbone_enabled", remote_name="superBackboneEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="export_limit", remote_name="exportLimit", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="export_to_overlay", remote_name="exportToOverlay", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -111,6 +126,9 @@ class NUOSPFInstance(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -151,6 +169,33 @@ class NUOSPFInstance(NURESTObject):
         self._ip_type = value
 
     
+    @property
+    def ospf_type(self):
+        """ Get ospf_type value.
+
+            Notes:
+                Type of the OSPF protocol, possible values are OSPFv2 and OSPFv3.
+
+                
+                This attribute is named `OSPFType` in VSD API.
+                
+        """
+        return self._ospf_type
+
+    @ospf_type.setter
+    def ospf_type(self, value):
+        """ Set ospf_type value.
+
+            Notes:
+                Type of the OSPF protocol, possible values are OSPFv2 and OSPFv3.
+
+                
+                This attribute is named `OSPFType` in VSD API.
+                
+        """
+        self._ospf_type = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -201,6 +246,33 @@ class NUOSPFInstance(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def last_updated_date(self):
+        """ Get last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        return self._last_updated_date
+
+    @last_updated_date.setter
+    def last_updated_date(self, value):
+        """ Set last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        self._last_updated_date = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -278,6 +350,33 @@ class NUOSPFInstance(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def creation_date(self):
+        """ Get creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        return self._creation_date
+
+    @creation_date.setter
+    def creation_date(self, value):
+        """ Set creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        self._creation_date = value
+
+    
     @property
     def preference(self):
         """ Get preference value.
@@ -382,6 +481,29 @@ class NUOSPFInstance(NURESTObject):
         self._super_backbone_enabled = value
 
     
+    @property
+    def owner(self):
+        """ Get owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        return self._owner
+
+    @owner.setter
+    def owner(self, value):
+        """ Set owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        self._owner = value
+
+    
     @property
     def export_limit(self):
         """ Get export_limit value.
